@@ -1,5 +1,5 @@
 package ZMQ::Raw::Message;
-$ZMQ::Raw::Message::VERSION = '0.10';
+$ZMQ::Raw::Message::VERSION = '0.12';
 use strict;
 use warnings;
 use Carp;
@@ -13,9 +13,16 @@ sub AUTOLOAD
     my $constname;
     our $AUTOLOAD;
     ($constname = $AUTOLOAD) =~ s/.*:://;
-    croak "&ZMQ::Raw::Message::_constant not defined" if $constname eq '_constant';
-    my ($error, $val) = _constant ($constname);
-    if ($error) { croak $error; }
+    croak "&ZMQ::Raw::Message::_constant not defined" if ($constname eq '_o_constant' || $constname eq '_p_constant');
+    my ($error, $val) = _o_constant ($constname);
+    if ($error)
+	{
+		($error, $val) = _p_constant ($constname);
+		if ($error)
+		{
+			croak $error;
+		}
+	}
     {
         no strict 'refs';
         *$AUTOLOAD = sub { $val };
@@ -31,7 +38,7 @@ ZMQ::Raw::Message - ZeroMQ Message class
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -74,16 +81,32 @@ Get the size in bytes of the content of the messsage.
 Get or set the routing id of the socket. To get a valid routing id, you must
 receive a message from a C<ZMQ_SERVER> socket.
 
+=head2 group( [$group] )
+
+Get or set the group socket.
+
 =head2 get( $property )
 
 Get the value of C<$property>.
 
+=head2 gets( $property )
+
+Get metadata property.
+
 =head1 CONSTANTS
 
 =head2 ZMQ_MORE
 
 =head2 ZMQ_SHARED
 
+=head2 ZMQ_MSG_PROPERTY_ROUTING_ID
+
+=head2 ZMQ_MSG_PROPERTY_SOCKET_TYPE
+
+=head2 ZMQ_MSG_PROPERTY_USER_ID
+
+=head2 ZMQ_MSG_PROPERTY_PEER_ADDRESS
+
 =head1 AUTHOR
 
 Jacques Germishuys <jacquesg@striata.com>
